write_feature_stream_raw

Function write_feature_stream_raw 

pub fn write_feature_stream_raw<W, I>(
    writer: W,
    models: I,
    options: &CityJsonSeqWriteOptions,
) -> Result<CityJsonSeqWriteReport, Error>
where W: Write, I: IntoIterator<Item = CityModel>,
Write a strict CityJSONSeq stream from feature models.

Errors

Returns an error if the feature models do not share compatible root state, if duplicate feature-local CityObject ids are present, or if stream serialization fails.